
dskellam=function(x,theta1,theta2)
  {
    exp(-(theta1+theta2)) *(theta1/theta2)^(x/2)*besselI(2*sqrt(theta1*theta2),nu=abs(x))
  }

cond=function(z,x,theta1,theta2,a)
  {
    if ( (x >=0)&(a>=0))
      {
        s=0:x
        r=(z-s)
        x1=dbinom(s,x,a)
        x2=dskellam(r,theta1,theta2)
        temp=sum(x1*x2) 
      } 
    if ((x<0)&(a>=0))
      {
        s=x:0
        r=(z-s)
        x1=dbinom(-s,abs(x),a)
        x2=dskellam(r,theta1,theta2)        
        temp=sum(x1*x2)
      }
    if ((x>=0)&(a<0))
      {
        s=  -x:0
        r=(z-s)
        x1=dbinom(-s,abs(x),abs(a))
        x2=dskellam(r,theta1,theta2)        
        temp=sum(x1*x2)
      }
    if ((x<0)&(a<0))
      {
        s= 0: (-x)
        r=(z-s)
        x1=dbinom(s,abs(x),abs(a))
        x2=dskellam(r,theta1,theta2)                
        temp=sum(x1*x2)
      }
    temp
  }


condloglik=function(theta,data)
  {
    theta1=theta[1]
    theta2=theta[2]
    a=theta[3]
    n=length(data)
    temp=0
    for (i in 2:n)
      {
        temp=temp + log(cond(data[i],data[i-1],theta1,theta2,a))
      }
    return(-temp)
  }

cond.restr.loglik=function(theta,data)
  {
    theta1=theta[1]
    theta2=theta[1]
    a=theta[2]
    n=length(data)
    temp=0
    for (i in 2:n)
      {
        temp=temp + log(cond(data[i],data[i-1],theta1,theta2,a))
      }
    return(-temp)
  }

condls=function(theta,data)
{
    theta1=theta[1]
    a=theta[2]    
    n=length(data)
    temp=0
    for (i in 2:n)
      {
        temp=temp + (data[i]-theta1-a*data[i-1])^2
      }
    return(temp)
  }

# READ DATA
x=as.matrix(read.table("tickdata1.dat",header=T))

# ESTIMATE FULL MODEL WITH CLS
fullCLS=nlm(condls,c(1,0.5),data=x,hessian=T)

# ESTIMATE FULL MODEL
fullML=nlm(condloglik,c(0.5,1,-0.23),data=x,hessian=T)
fullcovma=fullML$hessian
fullstderr=sqrt(diag(solve(fullcovma)))

# ESTIMATE MODEL WITH theta1=theta2
restrML=nlm(cond.restr.loglik,c(0.5,0.5),data=x,hessian=T)
restrcovma=restrML$hessian
restrstderr=sqrt(diag(solve(restrcovma)))

# LR-test
logLR=2*(restrML$minimum-fullML$minimum)
pvalue=1-pchisq(logLR,df=1)

# PREDICTED DISTRIBUTION
theta1=restrML$estimate[1]
theta2=restrML$estimate[1]
a=restrML$estimate[2]
vals=range(x)
r=vals[1]:vals[2]
pdf("conddist.pdf")
prob=c()
par(mfrow=c(3,1))
for(j in 3:5)
  {
    for(i in 1:length(r))
      {
        prob[i]=cond(r[i],r[j],theta1,theta2,a)
      }
    plot(r,prob,type="h",main=paste("x(t-1)=",r[j],sep=""),xlab="x(t)",ylim=c(0,1),xlim=c(-2,2))    
    abline(0,0)    
}
graphics.off()
